@@ -1,37 +1,38 @@
-function zoom_h() {
-  d3.select(this).attr("transform", "translate(" + d3.event.translate + ")scale(" + d3.event.scale + ")");
-}
-
 function d3_set_attr(selection, name, value) {
   selection.attr(name, value);
 }
 
+function zoomed() {
+    d3.select(this).attr("transform", d3.event.transform);
+}
+
 function select_data_id_single(selection, js_varname, svg_id) {
   selection.on("click", function(d,i) {
     d3.selectAll(svg_id + ' *[data-id]').classed('selected_', false);
     var dataid = d3.select(this).attr("data-id");
+
     if( window[js_varname][0] == dataid ){
       window[js_varname] = [];
     }
     else {
       window[js_varname] = [dataid];
-      d3.select(this).classed('selected_', true);
+      d3.selectAll(svg_id + ' *[data-id="' + dataid + '"]').classed('selected_', true);
     }
     Shiny.onInputChange(js_varname, window[js_varname]);
   });
 }
 
-function select_data_id_multiple(selection, js_varname) {
+function select_data_id_multiple(selection, js_varname, svg_id) {
   selection.on("click", function(d,i) {
 
     var dataid = d3.select(this).attr("data-id");
     var index = window[js_varname].indexOf(dataid);
     if( index < 0 ){
       window[js_varname].push( dataid );
-      d3.select(this).classed('selected_', true);
+      d3.selectAll(svg_id + ' *[data-id="' + dataid + '"]').classed('selected_', true);
     } else {
       window[js_varname].splice(index,1);
-      d3.select(this).classed('selected_', false);
+      d3.selectAll(svg_id + ' *[data-id="' + dataid + '"]').classed('selected_', false);
     }
 
     Shiny.onInputChange(js_varname, window[js_varname]);
@@ -59,7 +60,7 @@ HTMLWidgets.widget({
         window[el.id + '_canvas'] = '#svg_' + x.canvas_id;
         d3.select(el).attr("style", "text-align:center;");
         window[el.id + '_id'] = svg_id;
-        var tooltip_class = "tooltip" + x.data_id_class;
+        var tooltip_class = "tooltip" + x.canvas_id;
 
         // generate css elements
         var data_id_css = "." + x.data_id_class +  ":{}." +
@@ -91,7 +92,7 @@ HTMLWidgets.widget({
           if( x.selection_type == "single")
             sel_data_id.call(select_data_id_single, selected_id, svg_id);
           else if( x.selection_type == "multiple")
-            sel_data_id.call(select_data_id_multiple, selected_id);
+            sel_data_id.call(select_data_id_multiple, selected_id, svg_id);
 
           d3.selectAll(window[el.id + "_selected"]).each(function(d, i) {
             d3.selectAll(svg_id + ' *[data-id=\"'+ window[el.id + "_selected"][i] + '\"]').classed('selected_', true);
@@ -119,8 +120,9 @@ HTMLWidgets.widget({
           .classed("svg-content-responsive", true)
           .attr("width", "100%").attr("height", "100%");
         if(x.zoompan===true) {
-          var zoom_l = d3.behavior.zoom().scaleExtent([1, x.zoom_max]).on("zoom", zoom_h);
-          zoom_l(d3.select('#svg_' + x.canvas_id + ' g'));
+          d3.select('#svg_' + x.canvas_id + ' g').call(d3.zoom()
+                .scaleExtent([1, x.zoom_max])
+                .on("zoom", zoomed));
         }
         d3.select(el)
             .style( "position", "relative")
